@@ -1,7 +1,7 @@
 package Finance::Currency::FiatX;
 
-our $DATE = '2018-06-24'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2018-06-25'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -243,7 +243,7 @@ sub _get_all_spot_rates_or_get_spot_rate {
             if $source eq ':all';
         # in case user does this
         if ($from eq $to) {
-            return [304, "OK (identity)", 1];
+            return [304, "OK (identity)", {rate=>1}];
         }
     } else {
         $source or return [400, "Please specify from"];
@@ -654,7 +654,7 @@ Finance::Currency::FiatX - Fiat currency exchange rate library
 
 =head1 VERSION
 
-This document describes version 0.006 of Finance::Currency::FiatX (from Perl distribution Finance-Currency-FiatX), released on 2018-06-24.
+This document describes version 0.007 of Finance::Currency::FiatX (from Perl distribution Finance-Currency-FiatX), released on 2018-06-25.
 
 =head1 SYNOPSIS
 
